<?php defined('C5_EXECUTE') or die("Access Denied.");

/**
 * ab_yandex_maps package for Concrete5
 * Copyright Copyright 2017-2019, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_yandex_maps
 */
 
$al = $app->make('helper/concrete/asset_library');
?>

<style>
.ab-yandex-map-form .text-muted {
    font-size: 0.8em;
}
</style>

<fieldset class="ab-yandex-map-form">

    <div class="form-group">
        <div id="block_note" class="alert alert-info" role="alert">
        <?php echo t('Click on map to set location'); ?>
        </div>             
        <div id="ab_yandex_map" style="height: 300px; width: auto;"></div>
    </div>
        
    <div class="form-group">
        <?php
        echo $form->label('api_key', t('Yandex API Key'));
        echo $form->text('api_key', $api_key ? $api_key : '', ['maxlength' => 256]);
        echo '<p class="text-muted">' . t('Max 256 symbols') . ' (' . t('obtain API key at') . ' <a href="https://developer.tech.yandex.ru/" target="_blank">developer.tech.yandex.ru</a>)' . '</p>';
        ?>
    </div>
    
    <div class="form-group">
        <label class="control-label" for="location" name="location">
        <?php echo t('Location'); ?>
        <i class="launch-tooltip fa fa-question-circle" title="<?php echo t('Alternatively copy location from search field, this will become center of map'); ?>"></i>
        </label>
        <?php 
        echo $form->text('location', $location, ['maxlength' => 256]);
        echo '<p class="text-muted">' . t('Max 256 symbols') . '</p>';
        ?>
    </div>

    <div class="row">
        <div class="col-xs-6">
            <div class="form-group">
                <?php
                echo $form->label('latitude', t('Location latitude'));
                echo $form->text('latitude', $latitude ? $latitude : "55.753994", ['maxlength' => 20, 'class' => "decimals"]);
                echo '<p class="text-muted">' . t('Max 20 symbols, numeric only') . '</p>';
                ?>
            </div>
        </div>

        <div class="col-xs-6">
            <div class="form-group">
                <?php
                echo $form->label('longitude', t('Location longitude'));
                echo $form->text('longitude', $longitude ? $longitude : "37.622093", ['maxlength' => 20, 'class' => "decimals"]);
                echo '<p class="text-muted">' . t('Max 20 symbols, numeric only') . '</p>';
                ?>
            </div>
        </div>
    </div>
    
    <div class="row">
        <div class="col-xs-6">
            <div class="form-group">
                <label class="control-label" for="height" name="height">
                <?php echo t('Map height'); ?>
                <i class="launch-tooltip fa fa-question-circle" title="<?php echo h(t('Set map height with \'px\' or \'%\' only')); ?>"></i>
                </label>
                <div class="input-group">
                <span class="input-group-addon"><i class="fa fa-arrows-v"></i></span>
                <?php echo $form->text('height', $height ? $height : "300px", ['maxlength' => 6]); ?>
                </div>
                <?php echo '<p class="text-muted">' . t('Max 6 symbols') . '</p>'; ?>
            </div>
        </div>

        <div class="col-xs-6">
            <div class="form-group">
                <label class="control-label" for="width" name="width">
                <?php echo t('Map width'); ?>
                <i class="launch-tooltip fa fa-question-circle" title="<?php echo h(t('Set map width with \'px\' or \'%\' only')); ?>"></i>
                </label>
                <div class="input-group">
                <span class="input-group-addon"><i class="fa fa-arrows-h"></i></span>
                <?php echo $form->text('width', $width ? $width : "100%", ['maxlength' => 6]); ?>
                </div>
                <?php echo '<p class="text-muted">' . t('Max 6 symbols') . '</p>'; ?>
            </div>
        </div>
    </div>

    <div class="row">
        <div class="col-xs-6">
            <div class="form-group">
                <?php
                echo $form->label('zoom', t('Map zoom'));
                echo $form->number('zoom', $zoom ? $zoom : "12", ['min' => '1', 'max' => '16', 'class' => "decimals"]);
                echo '<p class="text-muted">' . t('Values from 1 to 16') . '</p>';
                ?>
            </div>
        </div>
    </div>
    
    <div class="form-group">
        <div class="checkbox">
            <label>
                <?php
                echo $form->checkbox('lock_wheel', 1, $lock_wheel);
                echo t('Enable mouse wheel zoom over map?');
                ?>
            </label>
        </div>
    </div>
    
    <div class="form-group">
        <div id="block_note" class="alert alert-info" role="alert">
        <?php echo t('Define info to show on map balloon and hint'); ?>
        </div>             
    </div>
    
    <div class="form-group">
        <div class="checkbox" data-checkbox-wrapper="show_name">
            <label>
                <?php
                echo $form->checkbox('show_name', 1, $show_name);
                echo t('Show name at location?');
                ?>
            </label>
        </div>
        <div data-fields="show_name" style="display: none">
            <div class="well">
                <div class="form-group">
                    <?php
                    echo $form->label('name', t('Location name'));
                    echo $form->text('name', $name, ['maxlength' => 256]);
                    echo '<p class="text-muted">' . t('Max 256 symbols') . '</p>';
                    ?>
                </div>
            </div>
        </div>
    </div>
    
    <div class="form-group">
        <div class="checkbox" data-checkbox-wrapper="show_address">
            <label>
                <?php
                echo $form->checkbox('show_address', 1, $show_address);
                echo t('Show alternative address at location?');
                ?>
            </label>
        </div>
        <div data-fields="show_address" style="display: none">
            <div class="well">
                <div class="form-group">
                    <?php
                    echo $form->label('address', t('Alternative location address'));
                    echo $form->text('address', $address, ['maxlength' => 256]);
                    echo '<p class="text-muted">' . t('Max 256 symbols') . '</p>';
                    ?>
                </div>
            </div>
        </div>
    </div>
    
    <div class="form-group">
        <div class="checkbox" data-checkbox-wrapper="show_tel">
            <label>
                <?php
                echo $form->checkbox('show_tel', 1, $show_tel);
                echo t('Show telephone at location?');
                ?>
            </label>
        </div>
        <div data-fields="show_tel" style="display: none">
            <div class="well">
                <div class="form-group">
                    <?php
                    echo $form->label('tel', t('Telephone'));
                    echo $form->text('tel', $tel, ['maxlength' => 256]);
                    echo '<p class="text-muted">' . t('Max 256 symbols') . '</p>';
                    ?>
                </div>
            </div>
        </div>
    </div>

    <div class="form-group">
        <div class="checkbox" data-checkbox-wrapper="show_email">
            <label>
                <?php
                echo $form->checkbox('show_email', 1, $show_email);
                echo t('Show email at location?');
                ?>
            </label>
        </div>
        <div data-fields="show_email" style="display: none">
            <div class="well">
                <div class="form-group">
                    <?php
                    echo $form->label('email', t('Email'));
                    echo $form->text('email', $email, ['maxlength' => 256]);
                    echo '<p class="text-muted">' . t('Max 256 symbols') . '</p>';
                    ?>
                </div>
            </div>
        </div>
    </div>

    <div class="form-group">
        <div class="checkbox" data-checkbox-wrapper="show_picture">
            <label>
                <?php
                echo $form->checkbox('show_picture', 1, $show_picture);
                echo t('Show picture at location?');
                ?>
            </label>
        </div>
        <div data-fields="show_picture" style="display: none">
            <div class="well">
                <div class="form-group">
                    <?php
                    echo $form->label('picture', t('Picture'));
                    echo $al->image('picture', 'pictureID', t('Choose picture'), $pic);
                    ?>
                </div>
            </div>
        </div>
    </div>

</fieldset>

<script type="text/javascript">
$(function(){
    var api_key = $('#api_key').val();
    var myYandexMap, myYandexPlacemark;
    var latitude = $('#latitude');
    var longitude = $('#longitude');
    
    loadScript('https://api-maps.yandex.ru/2.1/?apikey=' + api_key + '&lang=ru_RU', function(){
        ymaps.ready(function () {
            if (!api_key || api_key == '') {
                ConcreteAlert.error({
                    title: <?php echo json_encode(t('Empty Yandex API Key')); ?>,
                    message: <?php echo json_encode(t('Valid Yandex API Key should be provided')); ?>
                });
            }
            
            lat = $.trim(latitude.val()) == '' ? 55.753994 : $.trim(latitude.val());
            lon = $.trim(longitude.val()) == '' ? 37.622093 : $.trim(longitude.val());
            
            var myYandexMap = new ymaps.Map('ab_yandex_map', {
                center: [lat, lon],
                zoom: <?php echo $zoom ? $zoom : '12'; ?>,
                behaviors: ['default']
                }, {
                searchControlProvider: 'yandex#search'
            });
            
            var myYandexPlacemark = CreatePlacemark([lat, lon], $('#location').val());
            myYandexMap.geoObjects.add(myYandexPlacemark);

            // Слушаем клик на карте.
            myYandexMap.events.add('click', function(e) {
                var coords = e.get('coords');

                // Если метка уже создана – просто передвигаем ее.
                if (myYandexPlacemark) {
                    myYandexPlacemark.geometry.setCoordinates(coords);
                }
                // Если нет – создаем.
                else {
                    myYandexPlacemark = CreatePlacemark(coords, '<?php echo t('search...'); ?>');
                    myYandexMap.geoObjects.add(myYandexPlacemark);
                    // Слушаем событие окончания перетаскивания на метке.
                    myYandexPlacemark.events.add('dragend', function() {
                        GetAddress(myYandexPlacemark.geometry.getCoordinates(), '<?php echo t('search...'); ?>');
                    });
                }
                GetAddress(coords, '<?php echo t('search...'); ?>');
            });

            // Создание метки.
            function CreatePlacemark(coords, caption) {
                return new ymaps.Placemark(coords, {
                    iconCaption: caption
                }, {
                    preset: "islands#redHomeIcon",
                    draggable: true
                });
            };

            // Определяем адрес по координатам (обратное геокодирование).
            function GetAddress(coords, caption) {
                myYandexPlacemark.properties.set('iconCaption', caption);
                ymaps.geocode(coords).then(function(res) {
                    var firstGeoObject = res.geoObjects.get(0);

                    myYandexPlacemark.properties
                        .set({
                            // Формируем строку с данными об объекте.
                            iconCaption: [
                                // Название населенного пункта или вышестоящее административно-территориальное образование.
                                firstGeoObject.getLocalities().length ? firstGeoObject.getLocalities() : firstGeoObject.getAdministrativeAreas(),
                                // Получаем путь до топонима, если метод вернул null, запрашиваем наименование здания.
                                firstGeoObject.getThoroughfare() || firstGeoObject.getPremise()
                            ].filter(Boolean).join(', '),
                            // В качестве контента балуна задаем строку с адресом объекта.
                            balloonContent: firstGeoObject.getAddressLine()
                        });
                    $('#location').val(firstGeoObject.getAddressLine());
                    $('#latitude').val(coords[0]);
                    $('#longitude').val(coords[1]);
                });
            };
        });
    });
    
    $('.decimals').keydown(function (e) {
        // Allow: backspace, delete, tab, escape, enter and .
        if ($.inArray(e.keyCode, [46, 8, 9, 27, 13, 110, 190]) !== -1 ||
             // Allow: Ctrl+A, Command+A
            (e.keyCode === 65 && (e.ctrlKey === true || e.metaKey === true)) || 
             // Allow: home, end, left, right, down, up
            (e.keyCode >= 35 && e.keyCode <= 40)) {
                 // let it happen, don't do anything
                 return;
        }
        // Ensure that it is a number and stop the keypress
        if ((e.shiftKey || (e.keyCode < 48 || e.keyCode > 57)) && (e.keyCode < 96 || e.keyCode > 105)) {
            e.preventDefault();
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Oops')); ?>,
                message: <?php echo json_encode(t('Numbers only!')); ?>
            });
        }
    });

    $('#ccm-form-submit-button').on('click', function(e){
        var location = $.trim($('#location').val());
        if (location == '') {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Location value error:')); ?>,
                message: <?php echo json_encode(t('Location cannot be empty')); ?>
            });
        }
        
        var lat = $.trim(latitude.val());
        var lon = $.trim(longitude.val());
        if (lat == '' || lon == '') {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Coordinates value error:')); ?>,
                message: <?php echo json_encode(t('Coordinates cannot be empty')); ?>
            });
        }
        
        var zoom = parseInt($.trim($('#zoom').val()));
        if (zoom < 1 || zoom > 16) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Zoom value error:')); ?>,
                message: <?php echo json_encode(t('Zoom values can be from 1 to 16')); ?>
            });
        }
        
        var height = $.trim($('#height').val());
        var width = $.trim($('#width').val());
        var regex = /(\d)(px|%)$/;
        if (height == '' || !regex.test(height) || width == '' || !regex.test(width)) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Map height/width value error:')); ?>,
                message: <?php echo json_encode(t('Map height/width values cannot be empty and must end with with \'px\' or \'%\'')); ?>
            });
        }
        
        var email = $.trim($('#email').val());
        var regex = /^([_a-zA-Z0-9-]+)(\.[_a-zA-Z0-9-]+)*@([a-zA-Z0-9-]+)(\.[a-zA-Z0-9-]+)*(\.[a-zA-Z]{2,10})$/;
        if (email != '' && !regex.test(email)) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Email value error:')); ?>,
                message: <?php echo json_encode(t('Email address is not valid')); ?>
            });
        }
        
    });
    
    $('#show_name').on('change', function() {
        $('div[data-fields=show_name]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#name').val('');
        }
    }).trigger('change');

    $('#show_address').on('change', function() {
        $('div[data-fields=show_address]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#address').val('');
        }
    }).trigger('change');

    $('#show_tel').on('change', function() {
        $('div[data-fields=show_tel]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#tel').val('');
        }
    }).trigger('change');

    $('#show_email').on('change', function() {
        $('div[data-fields=show_email]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#email').val('');
        }
    }).trigger('change');

    $('#show_picture').on('change', function() {
        $('div[data-fields=show_picture]').toggle($(this).is(':checked'));
    }).trigger('change');

    function loadScript(url, callback){
        var script = document.createElement('script');
        script.type = 'text/javascript';
        script.setAttribute('src', url);

        script.onreadystatechange = callback;
        script.onload = callback;

        var head = document.getElementsByTagName('head')[0];
        head.appendChild(script, head);
    };
});
    
</script>
